%--------------------------------------------------------------------------------------------------%
%
% y = AlphaNormal(sigma,alpha,b1)
%   linear sum of parameterized normal densities
%
%   Parameters:
%       sigma - stress points (vector)
%       alpha - coefficients for basis functions (vector)
%       b1 - standard deviations for basis functions (vector)
%
%   Returns: 
%       y - corresponding density function
%
%   Required files: none
%                               
%                       ----------------------------
%
% Copyright (C) <2011> by <Ralph Smith (rsmith@ncsu.edu), John Crews(jhcrews@ncsu.edu)>
% <Department of Mathematics, North Carolina State University, Raleigh, NC 27695>
%
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
% associated documentation files (the "Software"), to deal in the Software without restriction,
% including without limitation the rights to use, copy, modify, merge, publish, distribute,
% sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
% furnished to do so, subject to the following conditions:
%
% The above copyright notice and this permission notice shall be included in all copies or
% substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
% NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
% DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
% OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%--------------------------------------------------------------------------------------------------%

function y = AlphaNormal(sigma,alpha,b1)

% linear sum of normal distributions
y = zeros(length(sigma),1);
for i=1:length(sigma)
    y(i) = sum(alpha.*exp(-0.5.*(sigma(i)./(b1)).^2)./(b1*sqrt(2*pi)));
end