%--------------------------------------------------------------------------------------------------%
%
% function  [x w] = gauss4()
%   calculates 4 point gaussian quadrature (points and weights)
%
%   Parameters:
%       none
%
%   Returns: 
%       x - quadrature points
%       w - quadrature weights
%
%   Required files: none
%                               
%                       ----------------------------
%
% Copyright (C) <2011> by <Ralph Smith (rsmith@ncsu.edu), John Crews(jhcrews@ncsu.edu)>
% <Department of Mathematics, North Carolina State University, Raleigh, NC 27695>
%
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
% associated documentation files (the "Software"), to deal in the Software without restriction,
% including without limitation the rights to use, copy, modify, merge, publish, distribute,
% sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
% furnished to do so, subject to the following conditions:
%
% The above copyright notice and this permission notice shall be included in all copies or
% substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
% NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
% DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
% OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%--------------------------------------------------------------------------------------------------%

function [x w] = gauss4()


x = [-0.5*1.0*sqrt((3.0 + 2.0*sqrt(6.0/5.0))/7.0)+0.5; ...
    -0.5*1.0*sqrt((3.0 - 2.0*sqrt(6.0/5.0))/7.0)+0.5; ...
    0.5*sqrt((3.0 - 2.0*sqrt(6.0/5.0))/7.0)+0.5;	...
    0.5*sqrt((3.0 + 2.0*sqrt(6.0/5.0))/7.0)+0.5];

w = [0.5*(18.0-sqrt(30.0))/36.0;...
    0.5*(18.0+sqrt(30.0))/36.0;...
    0.5*(18.0+sqrt(30.0))/36.0;...
    0.5*(18.0-sqrt(30.0))/36.0];

