%--------------------------------------------------------------------------------------------------%
%
% initialize_optimization_allparams.m
%   initializes design variables and bounds for optimization of density coefficients
%   and model parameters
%
%   Parameters:
%       none
%  
%   Returns: 
%       none (variables appear in workspace)
%
%   Required files: none
%                               
%                       ----------------------------
%
% Copyright (C) <2011> by <Ralph Smith (rsmith@ncsu.edu), John Crews(jhcrews@ncsu.edu)>
% <Department of Mathematics, North Carolina State University, Raleigh, NC 27695>
%
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
% associated documentation files (the "Software"), to deal in the Software without restriction,
% including without limitation the rights to use, copy, modify, merge, publish, distribute,
% sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
% furnished to do so, subject to the following conditions:
%
% The above copyright notice and this permission notice shall be included in all copies or
% substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
% NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
% DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
% OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%--------------------------------------------------------------------------------------------------%

% initialize optimization parameters and bounds
alpha0 = [0.1; 0.1; 0.5; 0.1; 0.1; 0.1;];
beta0 = [0.4; 0.4; 0.4; 0.2; 0.1];
nAlpha = length(alpha0);
nBeta = length(beta0);
xScaleSS = [1e10;1e10;1e8;1e7;0.01;1;1e-25];
x0 = [alpha0;beta0; params.Ea/xScaleSS(1);params.Em/xScaleSS(2); params.sigmaL/xScaleSS(3);...
     params.deltaSigmaTemp/xScaleSS(4); params.epsT/xScaleSS(5); params.tau/xScaleSS(6); params.V/xScaleSS(7)];
LB = [zeros(nAlpha,1); zeros(nBeta,1); 2e10/xScaleSS(1); 1e10/xScaleSS(2); 1e8/xScaleSS(3); 0.5e7/xScaleSS(4);0.03/xScaleSS(5); ...
    0.001/xScaleSS(6); 1e-26/xScaleSS(7)];
UB = [ones(nAlpha,1); ones(nBeta,1); 8e10/xScaleSS(1); 5e10/xScaleSS(2); 3e8/xScaleSS(3); 1.3e7/xScaleSS(4); 0.06/xScaleSS(5);...
    2/xScaleSS(6); 1e-23/xScaleSS(7)];

xScaleRes = [1e-7; 1e-7; 1e-4; 1e-4;0.05];
x0Res = [params.rhoA0; params.rhoM0; params.alphaA; params.alphaM; params.nu]./xScaleRes;
LBRes = [5e-7; 5e-7; 0.0001 ;0.0001 ;0.1]./xScaleRes;
UBRes = [15e-7; 15e-7 ;0.0008 ;0.0008; 0.8]./xScaleRes;