%--------------------------------------------------------------------------------------------------%
%
% load_experimental_data
%   loads stress-strain-resistance data and puts 65 and 80 C data into a
%   cell array for the optimization routine
%
%   Parameters:
%       none
%  
%   Returns: 
%       none (variables appear in workspace)
%
%   Required files: ConstantTempData.mat
%                               
%                       ----------------------------
%
% Copyright (C) <2011> by <Ralph Smith (rsmith@ncsu.edu), John Crews(jhcrews@ncsu.edu)>
% <Department of Mathematics, North Carolina State University, Raleigh, NC 27695>
%
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
% associated documentation files (the "Software"), to deal in the Software without restriction,
% including without limitation the rights to use, copy, modify, merge, publish, distribute,
% sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
% furnished to do so, subject to the following conditions:
%
% The above copyright notice and this permission notice shall be included in all copies or
% substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
% NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
% DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
% OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%--------------------------------------------------------------------------------------------------%

% load experimental data
infolder = './';
load([infolder 'ConstantTempData.mat']);

% select 65 and 80 for the optimization
exp_temp{1} = 65+273;
exp_temp{2} = 80+273;
exp_stress{1} = stress65_exp;
exp_stress{2} = stress80_exp;
exp_strain{1} = strain65_exp;
exp_strain{2} = strain80_exp;
exp_res{1} = res65_exp;
exp_res{2} = res80_exp;
exp_t{1} = t_exp;
exp_t{2} = t_exp;
app = '65and80';

% set initial phase fraction based on initial strain
sindex = find(exp_stress{1}>5e6,1,'first');
xp0 = (exp_strain{1}(sindex)+params.epsT)/(2*params.epsT);
ic{1} = [xp0 1-xp0];
ic{2} = [0 0];