%--------------------------------------------------------------------------------------------------%
%
% function R = resistance(strain,sigma,temp,xp,xm,xa,Em,Ea,rhoM0,rhoA0,alphaA,alphaM,TA,TM,L0,R0,nu)
%   sma resistance model
%
%   Parameters:
%       strain - strain (scalar or vector)
%       sigma - stress (scalar or vector)
%       temp - temperature (scalar or vector)
%       xp - martensite plus phase fraction (scalar or vector)
%       xm - martensite minus phase fraction (scalar or vector)
%       xa - austenite phase fraction (scalar or vector)
%       Em...nu - sma model parameters (see load_initial_parameters.m)
%  
%   Returns: 
%       R - resistance (scalar or vector)
%
%   Required files: 
%                               
%                       ----------------------------
%
% Copyright (C) <2011> by <Ralph Smith (rsmith@ncsu.edu), John Crews(jhcrews@ncsu.edu)>
% <Department of Mathematics, North Carolina State University, Raleigh, NC 27695>
%
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
% associated documentation files (the "Software"), to deal in the Software without restriction,
% including without limitation the rights to use, copy, modify, merge, publish, distribute,
% sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
% furnished to do so, subject to the following conditions:
%
% The above copyright notice and this permission notice shall be included in all copies or
% substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
% NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
% DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
% OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%--------------------------------------------------------------------------------------------------%

function R = resistance(strain,sigma,temp,xp,xm,xa,Em,Ea,rhoM0,rhoA0,alphaA,alphaM,TA,TM,L0,R0,nu)

rhoA = rhoA0*(1+alphaA*(temp-TA));
rhoM = rhoM0*(1+alphaM*(temp-TM));

rho = xa.*rhoA + (xm+xp).*rhoM;

epsE = sigma.*( (xp-xm)./Em + xa./Ea);

A = pi*R0^2*(1-nu*epsE).^2;
L = L0*(1+strain);

R = rho.*L./A;

