%--------------------------------------------------------------------------------------------------%
%
% function y = sma_strain(stress,xp,xm,xa,Ea,Em,epsT)
%   sma strain model
%
%   Parameters:
%       stress - stress (scalar or vector)
%       xp - martensite plus phase fraction (scalar or vector)
%       xm - martensite minus phase fraction (scalar or vector)
%       xa - austenite phase fraction (scalar or vector)
%       Ea - austenitic young's modulus
%       Em - martensitic young's modulus
%       epsT - maximum recoverable strain
%
%   Returns: 
%       y - strain (scalar or vector)
%
%   Required files: subinterval_pts.m, AlphaLogNormal.m, AlphaNormal.m,
%       pxx_he.m, sma_strain.m
%                               
%                       ----------------------------
%
% Copyright (C) <2011> by <Ralph Smith (rsmith@ncsu.edu), John Crews(jhcrews@ncsu.edu)>
% <Department of Mathematics, North Carolina State University, Raleigh, NC 27695>
%
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
% associated documentation files (the "Software"), to deal in the Software without restriction,
% including without limitation the rights to use, copy, modify, merge, publish, distribute,
% sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
% furnished to do so, subject to the following conditions:
%
% The above copyright notice and this permission notice shall be included in all copies or
% substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
% NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
% DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
% OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%--------------------------------------------------------------------------------------------------%

function y = sma_strain(stress,xp,xm,xa,Ea,Em,epsT)

y = xa.*(stress/Ea)+xp.*(stress/Em+epsT) + xm.*(stress/Em-epsT);