%--------------------------------------------------------------------------------------------------%
%
% function [x w] = subinterval_pts(Npts, NsubInts, LB, UB)
%   calculates the 4 point gaussian quadrature points and weights on the
%   number of subintervals between the bounds
%
%   Parameters:
%       Npts - n point gaussian quadrature (currently supports only 4)
%       NsubInts - number of subintervals
%       LB - lower bound
%       UB - upper bound
%
%   Returns: 
%       x - quadrature points
%       w - quadrature weights
%
%   Required files: gauss4.m
%                               
%                       ----------------------------
%
% Copyright (C) <2011> by <Ralph Smith (rsmith@ncsu.edu), John Crews(jhcrews@ncsu.edu)>
% <Department of Mathematics, North Carolina State University, Raleigh, NC 27695>
%
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
% associated documentation files (the "Software"), to deal in the Software without restriction,
% including without limitation the rights to use, copy, modify, merge, publish, distribute,
% sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
% furnished to do so, subject to the following conditions:
%
% The above copyright notice and this permission notice shall be included in all copies or
% substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
% NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
% NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
% DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
% OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%--------------------------------------------------------------------------------------------------%

function [x w] = subinterval_pts(Npts, NsubInts, LB, UB)

% calculate gauss points (only 4 right now)
if( Npts == 4)
    [gauss_x gauss_w]  = gauss4();
else
    [gauss_x gauss_w]  = gauss4();
end

% temporary output
xtemp = LB:(UB-LB)/NsubInts:UB;

% initialize output
x=length(gauss_x)*NsubInts;
w=length(gauss_x)*NsubInts;

ind = 1;
for i =1:length(xtemp)-1
    
    x(ind:ind+Npts-1,1) = xtemp(i)+gauss_x(:).*(xtemp(i+1) - xtemp(i));
    w(ind:ind+Npts-1,1) = gauss_w;
    
    ind = ind+4;
end
